# Center in box

Center a group of atoms in a box using [`MDAnalysis.transformations.translate.center_in_box`](https://docs.mdanalysis.org/stable/documentation_pages/transformations/translate.html#MDAnalysis.transformations.translate.center_in_box).

<video controls>
  <source src="../../movies/mda-tui-center-in-box.mp4" type="video/mp4">
</video>
